@@ -5,6 +5,7 @@ import os
 import unittest
 
 import ioc
+import sqlalchemy
 from ioc.loader import import_symbol
 from sqlalchemy import create_engine
 from sqlalchemy import event
@@ -149,7 +150,8 @@ class TestDatabaseManager:
         # Loop over the discovered database connections to create the engine
         # objects.
         for name, opts in dict.items(self.databases):
-            self.engines[name] = engine = opts.as_engine(create_engine, echo=True)
+            self.engines[name] = engine = opts.as_engine(
+                sqlalchemy.create_engine, echo=True)
             if name == 'self':
                 for Base in self.bases:
                     Base.metadata.create_all(engine)
